AnimatedSegment class

Inheritance

Constructors

AnimatedSegment({required List<String> segmentNames, required ValueChanged<int> onSegmentChanged, int? initialSegment, Color backgroundColor = AppColors.bgColor, Color segmentTextColor = AppColors.primary, Color selectedSegmentColor = AppColors.white, Color rippleEffectColor = AppColors.white, Key? key})
const

Properties

backgroundColor → Color
backgroundColor property takes Color value as a parameter. You can change the background color of animated segment. default value is Color(0xff8AADFB)
final
hashCode → int
The hash code for this object.
no setterinherited
initialSegment → int?
initialSegment property takes int value as a parameter. This is use to set the initial segment from segmentNames.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSegmentChanged → ValueChanged<int>
onSegmentChanged Call back called when the user select the new segment and return the selected segment index. Index for the initial selected segment is 0.
final
rippleEffectColor → Color
rippleEffectColor property takes Color value as a parameter. You can change the ripple color of segment. default value is Colors.white
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentNames → List<String>
segmentNames property takes List
final
segmentTextColor → Color
segmentTextColor property takes Color value as a parameter. You can change the text color of segmented text color. default value is Color(0xff0217FD)
final
selectedSegmentColor → Color
selectedSegmentColor property takes Color value as a parameter. You can change the selected segment color of animated segment. default value is Colors.white
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AnimatedSegmentState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited