Dimens class

Dimens class have all the static and const members. Here, we have defined used dimensions inside the package.

Constructors

Dimens()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

animationDurationNormal → const int
animationDurationSmall → const int
heightNormal → const double
heightSmall → const double
paddingLarge → const double
paddingNormal → const double
paddingSmall → const double
paddingXLarge → const double
radiusLarge → const double
textNormal → const double